@@ -1,4 +1,3 @@
-
 mbco_parametric <- function(h0 = NULL,
                             h1 = NULL,
                             R = 10L,
@@ -13,15 +12,18 @@ mbco_parametric <- function(h0 = NULL,
   OpenMx::mxOption(NULL, "Default optimizer", optim)
 
   res <- OpenMx::mxCompare(h1,
-                           h0,
-                           boot = TRUE,
-                           replications = R)
-  mbco_chisq <- res$diffLL[2]  # Chi-square
-  mbco_pvalue <- res$p[2]   # p-value
+    h0,
+    boot = TRUE,
+    replications = R
+  )
+  mbco_chisq <- res$diffLL[2] # Chi-square
+  mbco_pvalue <- res$p[2] # p-value
   mbco_df <- res$df[2] - res$df[1] # df
   mbcoTest <-
-    list(chisq = mbco_chisq,
-         df = mbco_df,
-         p = mbco_pvalue)
+    list(
+      chisq = mbco_chisq,
+      df = mbco_df,
+      p = mbco_pvalue
+    )
   return(mbcoTest)
 }
