@@ -37,46 +37,32 @@
 #'   Research Methods}, \bold{43}, 692--700. doi:10.3758/s13428-011-0076-x
 #' @seealso \code{\link{medci}} \code{\link{RMediation-package}}
 #' @examples
-#' pprodnormal(q=0, mu.x=.5, mu.y=.3, se.x=1, se.y=1, rho= 0, type="all")
+#' pprodnormal(q = 0, mu.x = .5, mu.y = .3, se.x = 1, se.y = 1, rho = 0, type = "all")
+#' @importFrom checkmate assert_numeric assert_logical assert_count
 #' @export
+pprodnormal <- function(q, mu.x, mu.y, se.x = 1, se.y = 1, rho = 0, lower.tail = TRUE, type = "dop", n.mc = 1e5) {
+  # Input validation
+  assert_numeric(q, finite = TRUE, len = 1)
+  assert_numeric(mu.x, finite = TRUE)
+  assert_numeric(mu.y, finite = TRUE)
+  assert_numeric(se.x, lower = 0, finite = TRUE)
+  assert_numeric(se.y, lower = 0, finite = TRUE)
+  assert_numeric(rho, lower = -1, upper = 1, finite = TRUE)
+  assert_logical(lower.tail)
+  type <- match.arg(type, c("dop", "MC", "all"))
+  assert_count(n.mc, positive = TRUE)
 
-
-pprodnormal<- function(q, mu.x, mu.y, se.x=1, se.y=1, rho=0, lower.tail=TRUE, type="dop", n.mc=1e5){
-  if(!is.numeric(mu.x))
-    stop("Argument mu.x must be numeric!")
-  if(!is.numeric(mu.y))
-    stop("Argument mu.y must be numeric!")
-  if(!is.numeric(se.x))
-    stop("Argument se.x must be numeric!")
-  if(!is.numeric(se.y))
-      stop("Argument se.y must be numeric!")
-  if(!is.numeric(rho))
-      stop("Argument rho  must be numeric!")
-  if(rho<=-1 || rho>=1)
-    stop("rho must be between -1 and 1!")
-  if(!is.numeric(n.mc) || is.null(n.mc))
-    n.mc=1e5 # sets n.mc to default
-
-  if (type=="all" || type=="All" || type=="ALL")
-    {
-        p2 <- pprodnormalMeeker(q, mu.x, mu.y, se.x, se.y, rho, lower.tail)
-        ##cat("Monte Carlo method:\n")
-        p3 <- pprodnormalMC(q, mu.x, mu.y, se.x, se.y, rho, lower.tail, n.mc)
-        res <- list(p2,p3)
-        names(res) <- c( "Distribution of Product", "Monte Carlo")
-        return(res)
-    }
-  else if (type=="DOP" || type=="dop")
-    {
-        ##cat("Meeker method:\n")
-        p2 <- pprodnormalMeeker(q, mu.x, mu.y, se.x, se.y, rho, lower.tail)
-        return(p2)
-    }
-  else if (type=="MC" || type=="mc" || type=="Mc")
-    {
-        ##cat("Monte Carlo method:\n")
-        p3 <- pprodnormalMC(q, mu.x, mu.y, se.x, se.y, rho, lower.tail, n.mc)
-        return(p3)
-    }
-  else stop("Wrong type! please specify type=\"all\", \"DOP\", or \"MC\" ")
+  if (type == "all") {
+    p2 <- pprodnormalMeeker(q, mu.x, mu.y, se.x, se.y, rho, lower.tail)$p
+    p3 <- pprodnormalMC(q, mu.x, mu.y, se.x, se.y, rho, lower.tail, n.mc)$p
+    res <- list(p2, p3)
+    names(res) <- c("Distribution of Product", "Monte Carlo")
+    return(res)
+  } else if (type == "dop") {
+    p2 <- pprodnormalMeeker(q, mu.x, mu.y, se.x, se.y, rho, lower.tail)$p
+    return(p2)
+  } else if (type == "MC") {
+    p3 <- pprodnormalMC(q, mu.x, mu.y, se.x, se.y, rho, lower.tail, n.mc)$p
+    return(p3)
+  }
 }
